@@ -64,6 +64,9 @@ def get_libraries():
     :returns: List of library names
     :rtype: list
 
+    >>> len(get_libraries()) >= 1
+    True
+
     """
     libs = []
     config = papis.config.get_configuration()
@@ -73,14 +76,24 @@ def get_libraries():
     return libs
 
 
-def pick_doc(documents):
+def pick_doc(documents: list):
     """Pick a document from documents with the correct formatting
 
     :documents: List of documents
     :returns: Document
 
+    >>> from papis.document import from_data
+    >>> doc = from_data({'title': 'Hello World'})
+    >>> pick_doc([doc]).dump()
+    'title:   Hello World\\n'
+
     """
-    header_format = papis.config.get("header-format")
+    header_format_path = papis.config.get('header-format-file')
+    if header_format_path is not None:
+        with open(os.path.expanduser(header_format_path)) as fd:
+            header_format = fd.read()
+    else:
+        header_format = papis.config.get("header-format")
     match_format = papis.config.get("match-format")
     pick_config = dict(
         header_filter=lambda x: papis.utils.format_doc(header_format, x),
@@ -92,7 +105,7 @@ def pick_doc(documents):
     )
 
 
-def pick(options, pick_config={}):
+def pick(options: list, pick_config={}):
     """This is a wrapper for the various pickers that are supported.
     Depending on the configuration different selectors or 'pickers'
     are used.
@@ -112,16 +125,18 @@ def pick(options, pick_config={}):
     >>> papis.config.set('picktool', 'papis.pick')
     >>> pick(['something'])
     'something'
+    >>> papis.config.set('picktool', 'nonexistent')
+    >>> pick(['something'])
+    Traceback (most recent call last):
+    ...
+    Exception: I don\'t know how to use the picker \'nonexistent\'
+    >>> papis.config.set('picktool', 'papis.pick')
 
     """
     # Leave this import here
     import papis.config
     logger.debug("Parsing picktool")
     picker = papis.config.get("picktool")
-    if picker == "rofi":
-        import papis.gui.rofi
-        logger.debug("Using rofi picker")
-        return papis.gui.rofi.pick(options, **pick_config)
     if picker == "dmenu":
         import papis.gui.dmenu
         logger.debug("Using dmenu picker")
@@ -177,6 +192,26 @@ def edit_file(file_path, wait=True):
     papis.utils.general_open(file_path, "editor", wait=wait)
 
 
+def get_all_documents_in_lib(library=None):
+    """Get ALL documents contained in the given library with possibly.
+
+    :param library: Library name.
+    :type  library: str
+
+    :returns: List of all documents.
+    :rtype: list
+
+    >>> import tempfile
+    >>> folder = tempfile.mkdtemp()
+    >>> set_lib(folder)
+    >>> docs = get_all_documents_in_lib(folder)
+    >>> len(docs)
+    0
+
+    """
+    return papis.database.get(library=library).get_all_documents()
+
+
 def get_documents_in_dir(directory, search=""):
     """Get documents contained in the given folder with possibly a search
     string.
@@ -214,7 +249,7 @@ def get_documents_in_lib(library=None, search=""):
     :rtype: list
 
     """
-    return papis.database.get().query(search)
+    return papis.database.get(library=library).query(search)
 
 
 def clear_lib_cache(lib=None):
@@ -224,6 +259,8 @@ def clear_lib_cache(lib=None):
     :param lib: Library name.
     :type  lib: str
 
+    >>> clear_lib_cache()
+
     """
     lib = papis.api.get_lib() if lib is None else lib
     papis.database.get(lib).clear()
