@@ -53,11 +53,6 @@
     User agent used by papis whenever it obtains information from external
     servers.
 
-.. papis-config:: default-gui
-
-    Default gui to be used by papis, it can have the values given
-    by ``papis gui --help``.
-
 .. papis-config:: scripts-short-help-regex
 
     This is the format of the short help indicator in external papis
@@ -101,6 +96,41 @@
 
     Default format that is used to show a document in order to select it.
 
+.. papis-config:: format-jinja2-enable
+
+    This setting is to enable the `jinja2 <http://jinja.pocoo.org//>`_ template
+    engine to render the papis templates being used, as ``header-format``,
+    ``match-format`` etc...
+
+    For instance you could set the option ``header-format`` to
+
+    .. code:: html
+
+        <span color='#ff00ff'>{{doc.html_escape["title"]}}</span>
+        <span color='#00ff00'>  {{doc.html_escape["author"]}}</span>
+        <span color='#00ffaa'>   ({{doc.html_escape["year"]}}) </span>
+        {%- if doc.has('tags') %}<span>[<yellow>{{doc['tags']}}</yellow>] </span>{%- endif %}
+        {%- if doc.has('citations') %}<red>{{doc['citations']|length}}</red>{%- endif %}
+        {%- if doc.has('url') %}
+        <span>    {{doc.html_escape["url"]}}</span>
+        {%- endif %}
+
+    To use it, just install jinja2.
+
+.. papis-config:: header-format-file
+
+    This option should have the path of a file with the ``header-format``
+    template. Sometimes templates can get big so this is a way
+    of not cluttering the config file with text.
+
+    As an example you would set
+
+    .. code:: ini
+
+        [papers]
+
+        header-format-file = ~/.papis/config/styles/header.txt
+
 .. papis-config:: info-allow-unicode
 
     This flag is to be set if you want to allow unicode characters
@@ -109,10 +139,6 @@
     Since we should be living in an unicode world, it is set to ``True``
     by default.
 
-.. papis-config:: sync-command
-
-    Command that is to be used when ``papis sync`` is run.
-
 Tools options
 ^^^^^^^^^^^^^
 
@@ -139,7 +165,6 @@ Tools options
 
     Possible options are:
         - papis.pick
-        - rofi
         - vim
         - dmenu
 
@@ -168,6 +193,15 @@ Tools options
 Bibtex options
 ^^^^^^^^^^^^^^
 
+.. papis-config:: bibtex-journal-key
+
+    Journal publishers may request abbreviated journal titles. This
+    option allows the user to set the key for the journal entry when using
+    ``papis export --bibtex``.
+
+    Set as ``full_journal_title`` or ``abbrev_journal_title`` for
+    whichever style required. Default is ``journal``.
+
 .. papis-config:: extra-bibtex-keys
 
     When exporting documents in bibtex format, you might want to add
@@ -266,30 +300,21 @@ Add command options
     will fave the contrary effect, i.e., it will not open the attached files
     before adding the document to the library.
 
-.. papis-config:: add-default-fields
+Browse command options
+^^^^^^^^^^^^^^^^^^^^^^
 
-    This is the default values that are settable in the add command.
-    For instance if you would like to set ``title``, ``author`` and
-    ``year`` directly from the command line, you can set
-    ::
+.. papis-config:: browse-key
 
-        add-default-fields = ['title', 'author', 'year']
+    This command provides the key that is used to generate the
+    url. For users that ``papis add --from-doi``, setting browse-key
+    to ``doi`` constructs the url from dx.doi.org/DOI, providing a
+    much more accurate url.
 
-    and you will be able to do
-    ::
+    Default value is set to ``url``. If the user needs functionality
+    with the ``search-engine`` option, set the option to an empty
+    string e.g.  ::
 
-        papis add doc.pdf --author 'Bohm' --title 'Super book' --year 1928
-
-.. _check-command-options:
-
-Check command options
-^^^^^^^^^^^^^^^^^^^^^
-
-.. papis-config:: check-keys
-
-    Python list key values to be checked by default by the command
-    ``check``. E.g: ``check-keys = ["author", "doi"]``.
-    It is important that it is a valid python list.
+        browse-key = ''
 
 .. _edit-command-options:
 
@@ -374,6 +399,15 @@ Marks
 
             mark-opener-format = zathura -P {mark[value]}
 
+Downloaders
+===========
+
+.. papis-config:: downloader-proxy
+
+    There is the possibility of download papers using a proxy.
+    To know more you can checkout this
+    `link <http://docs.python-requests.org/en/master/user/advanced/#proxies>`_.
+
 Databases
 =========
 
@@ -430,6 +464,28 @@ Databases
     `the documentation <https://whoosh.readthedocs.io/en/latest/schema.html/>`_
     for more information.
 
+Other
+=====
+
+.. papis-config:: citation-string
+
+    string that can be displayed in header if the reference has a
+    citation
+
+    Default set to '*'
+
+.. papis-config:: unique-document-keys
+
+    Whenever you add a new document, papis tries to figure out if
+    you have already added this document before. This is partially done
+    checking for some special keys, and checking if they match.
+    Which keys are checked against is decided by this option, which
+    should be formatted as a python list, just as in the default value.
+
+    For instance, if you add a paper with a given ``doi``, and then you
+    add another document with the same ``doi``, then papis will notify
+    you that there is already another document with this ``doi`` because
+    the ``doi`` key is part of the ``unique-document-keys`` option.
 
 """
 import logging
@@ -442,9 +498,9 @@ import configparser
 import papis.exceptions
 
 
-CONFIGURATION = None  #: Global configuration object variable.
-DEFAULT_SETTINGS = None  #: Default settings for the whole papis.
-OVERRIDE_VARS = {
+_CONFIGURATION = None  #: Global configuration object variable.
+_DEFAULT_SETTINGS = None  #: Default settings for the whole papis.
+_OVERRIDE_VARS = {
     "folder": None,
     "cache": None,
     "file": None,
@@ -478,7 +534,6 @@ general_settings = {
                         or os.environ.get('VISUAL')
                         or get_default_opener(),
     "xeditor": get_default_opener(),
-    "sync-command": "git -C {lib[dir]} pull origin master",
     "notes-name": "notes.tex",
     "use-cache": True,
     "cache-dir": None,
@@ -490,13 +545,11 @@ general_settings = {
     "add-interactive": False,
     "add-edit": False,
     "add-open": False,
-    "add-default-fields": '["title", "author"]',
 
-    "check-keys": '["files"]',
+    "browse-key": 'url',
     "browse-query-format": "{doc[title]} {doc[author]}",
     "search-engine": "https://duckduckgo.com",
     "user-agent": 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_3)',
-    "default-gui": "vim",
     "scripts-short-help-regex": ".*papis-short-help: *(.*)",
     "info-name": "info.yaml",
     "doc-url-key-name": "doc_url",
@@ -509,6 +562,7 @@ general_settings = {
     "mark-opener-format": get_default_opener(),
 
     "file-browser": get_default_opener(),
+    "bibtex-journal-key": 'journal',
     "extra-bibtex-keys": "",
     "extra-bibtex-types": "",
     "default-library": "papers",
@@ -518,8 +572,13 @@ general_settings = {
     "format-doc-name": "doc",
     "match-format":
         "{doc[tags]}{doc.subfolder}{doc[title]}{doc[author]}{doc[year]}",
-    "header-format":
-        "{doc[title]:<70.70}|{doc[author]:<20.20} ({doc[year]:-<4})",
+    "format-jinja2-enable": False,
+    "header-format-file": None,
+    "header-format": \
+        "<red>{doc.html_escape[title]}</red>\n"\
+        " <span color='#00ff00'>{doc.html_escape[author]}</span>\n"
+        "  <span color='#00ffaa'>({doc.html_escape[year]})</span> "
+        "[<yellow>{doc.html_escape[tags]}</yellow>]",
 
     "info-allow-unicode": True,
     "ref-format": "{doc[doi]}",
@@ -535,6 +594,12 @@ general_settings = {
     '"tags": TEXT(stored=True),\n'
     '}',
 
+    "citation-string": "*",
+    'unique-document-keys': "['doi','ref','isbn','isbn10','url','doc_url']",
+
+    "tui-editmode": "emacs",
+    "downloader-proxy": None,
+
 }
 
 
@@ -568,28 +633,77 @@ def get_default_settings(section="", key=""):
     True
     >>> get_default_settings(key='mvtool')
     'mv'
+    >>> get_default_settings(key='mvtool', section='settings')
+    'mv'
     >>> get_default_settings(key='help-key', section='vim-gui')
     'h'
     """
-    global DEFAULT_SETTINGS
+    global _DEFAULT_SETTINGS
     import papis.gui
     # We use an OrderedDict so that the first entry will always be the general
     # settings, also good for automatic documentation
     from collections import OrderedDict
-    if DEFAULT_SETTINGS is None:
-        DEFAULT_SETTINGS = OrderedDict()
-        DEFAULT_SETTINGS.update({
+    if _DEFAULT_SETTINGS is None:
+        _DEFAULT_SETTINGS = OrderedDict()
+        _DEFAULT_SETTINGS.update({
             get_general_settings_name(): general_settings,
         })
-        DEFAULT_SETTINGS.update(
+        _DEFAULT_SETTINGS.update(
             papis.gui.get_default_settings()
         )
     if not section and not key:
-        return DEFAULT_SETTINGS
+        return _DEFAULT_SETTINGS
     elif not section:
-        return DEFAULT_SETTINGS[get_general_settings_name()][key]
+        return _DEFAULT_SETTINGS[get_general_settings_name()][key]
     else:
-        return DEFAULT_SETTINGS[section][key]
+        return _DEFAULT_SETTINGS[section][key]
+
+
+def register_default_settings(settings_dictionary):
+    """Register configuration settings into the global configuration registry.
+
+    Notice that you can define sections or global options. For instance,
+    let us suppose that a script called ``hubation`` defines some
+    configuration options. In the script there could be the following defined
+
+    ::
+
+        import papis.config
+        options = {'hubation': { 'command': 'open'}}
+        papis.config.register_default_settings(options)
+
+    and later on the script can use these options as:
+
+    ::
+
+        papis.config.get('command', section='hubation')
+
+    :param settings_dictionary: A dictionary with settings
+    :type  settings_dictionary: dict
+    >>> papis.config.register_default_settings(\
+            {'scihub': { 'command': 'open'}}\
+        )
+    >>> papis.config.get('command', section='scihub')
+    'open'
+    >>> options = {'settings': { 'hubhub': 42, 'default-library': 'mag' }}
+    >>> papis.config.register_default_settings(options)
+    >>> papis.config.get('hubhub')
+    42
+    >>> papis.config.get('info-name') is not None
+    True
+    >>> not papis.config.get('default-library') == 'mag'
+    True
+    >>> papis.config.get_default_settings(key='default-library') == 'mag'
+    True
+    """
+    default_settings = get_default_settings()
+    # we do a for loop because apparently the OrderedDict removes all
+    # key-val fields after updating, so we have to do it by hand
+    for section in settings_dictionary.keys():
+        if section in default_settings.keys():
+            default_settings[section].update(settings_dictionary[section])
+        else:
+            default_settings[section] = settings_dictionary[section]
 
 
 def get_config_home():
@@ -598,21 +712,17 @@ def get_config_home():
 
     :returns: Configuration base directory
     :rtype:  str
-    >>> import os; os.environ['XDG_CONFIG_HOME'] = '/tmp'
-    >>> get_config_home()
-    '/tmp'
     """
-    return os.environ.get('XDG_CONFIG_HOME') or os.path.join(
-        os.path.expanduser('~'), '.config'
-    )
+    xdg_home = os.environ.get('XDG_CONFIG_HOME')
+    if xdg_home:
+        return os.path.expanduser(xdg_home)
+    else:
+        return os.path.join(os.path.expanduser('~'), '.config')
 
 
 def get_config_dirs():
-    """
-    >>> import os; os.environ['XDG_CONFIG_DIRS'] = ''
-    >>> os.environ['XDG_CONFIG_HOME'] = '/tmp'
-    >>> get_config_dirs()
-    ['/tmp/papis', ...]
+    """Get papis configuration directories where the configuration
+    files might be stored
     """
     dirs = []
     if os.environ.get('XDG_CONFIG_DIRS'):
@@ -636,11 +746,6 @@ def get_config_folder():
     environment variable ``XDG_CONFIG_HOME`` is defined it will use the
     configuration folder ``XDG_CONFIG_HOME/papis`` instead.
 
-    >>> import os; os.environ['XDG_CONFIG_HOME'] = '/tmp'
-    >>> newpath = os.path.join(os.environ['XDG_CONFIG_HOME'], 'papis')
-    >>> if not os.path.exists(newpath): os.mkdir(newpath)
-    >>> get_config_folder()
-    '/tmp/papis'
     """
     config_dirs = get_config_dirs()
     for config_dir in config_dirs:
@@ -653,16 +758,10 @@ def get_config_folder():
 def get_config_file():
     """Get the path of the main configuration file,
     e.g. /home/user/.papis/config
-
-    >>> import os; os.environ['XDG_CONFIG_HOME'] = '/tmp'
-    >>> newpath = os.path.join(os.environ['XDG_CONFIG_HOME'], 'papis')
-    >>> if not os.path.exists(newpath): os.mkdir(newpath)
-    >>> get_config_file()
-    '/tmp/papis/config'
     """
-    global OVERRIDE_VARS
-    if OVERRIDE_VARS["file"] is not None:
-        config_file = OVERRIDE_VARS["file"]
+    global _OVERRIDE_VARS
+    if _OVERRIDE_VARS["file"] is not None:
+        config_file = _OVERRIDE_VARS["file"]
     else:
         config_file = os.path.join(
             get_config_folder(), "config"
@@ -674,10 +773,9 @@ def get_config_file():
 def set_config_file(filepath):
     """Override the main configuration file path
     """
-    global OVERRIDE_VARS
-    if filepath is not None:
-        logger.debug("Setting config file to %s" % filepath)
-        OVERRIDE_VARS["file"] = filepath
+    global _OVERRIDE_VARS
+    logger.debug("Setting config file to %s" % filepath)
+    _OVERRIDE_VARS["file"] = filepath
 
 
 def get_scripts_folder():
@@ -692,15 +790,13 @@ def get_scripts_folder():
 def set(key, val, section=None):
     """Set a key to val in some section and make these changes available
     everywhere.
-    >>> set('picktool', 'rofi')
-    >>> get('picktool')
-    'rofi'
     """
     config = get_configuration()
     if not config.has_section(section or "settings"):
         config.add_section(section or "settings")
     # FIXME: Right now we can only save val in string form
     # FIXME: It would be nice to be able to save also int and booleans
+    # FIXME: configparser seems to be able to only store string values
     config.set(section or get_general_settings_name(), key, str(val))
 
 
@@ -801,33 +897,29 @@ def get_configuration():
     :returns: Configuration object
     :rtype:  papis.config.Configuration
     """
-    global CONFIGURATION
-    if CONFIGURATION is None:
+    global _CONFIGURATION
+    if _CONFIGURATION is None:
         logger.debug("Creating configuration")
-        CONFIGURATION = Configuration()
+        _CONFIGURATION = Configuration()
         # Handle local configuration file, and merge it if it exists
         local_config_file = papis.config.get("local-config-file")
-        merge_configuration_from_path(local_config_file, CONFIGURATION)
-    return CONFIGURATION
+        merge_configuration_from_path(local_config_file, _CONFIGURATION)
+    return _CONFIGURATION
 
 
 def merge_configuration_from_path(path, configuration):
     """
     Merge information of a configuration file found in `path`
     to the information of the configuration object stored in `configuration`.
-    The function checks for the existence of path.
 
     :param path: Path to the configuration file
     :type  path: str
     :param configuration: Configuration object
     :type  configuration: papis.config.Configuration
     """
-    if os.path.exists(path):
-        logger.debug(
-            "Merging configuration from " + path
-        )
-        configuration.read(path)
-        configuration.handle_includes()
+    logger.debug("Merging configuration from " + path)
+    configuration.read(path)
+    configuration.handle_includes()
 
 
 def set_lib(library):
@@ -836,13 +928,6 @@ def set_lib(library):
     :param library: Library name or path to a papis library
     :type  library: str
 
-    >>> import os
-    >>> if not os.path.exists('/tmp/setlib-test'): os.makedirs(\
-            '/tmp/setlib-test'\
-        )
-    >>> set_lib('/tmp/setlib-test')
-    >>> get_lib()
-    '/tmp/setlib-test'
     """
     config = get_configuration()
     if library not in config.keys():
@@ -854,11 +939,8 @@ def set_lib(library):
             raise Exception(
                 "Path or library '%s' does not seem to exist" % library
             )
-    try:
-        args = papis.commands.get_args()
-        args.lib = library
-    except AttributeError:
-        os.environ["PAPIS_LIB"] = library
+    os.environ["PAPIS_LIB"] = library
+    os.environ["PAPIS_LIB_DIR"] = get('dir')
 
 
 def get_lib():
@@ -868,20 +950,13 @@ def get_lib():
 
     :param library: Name of library or path to a given library
     :type  library: str
-    >>> set_lib('papers')
-    >>> get_lib()
-    'papers'
     """
-    import papis.commands
     try:
-        lib = papis.commands.get_args().lib
-    except AttributeError:
-        try:
-            lib = os.environ["PAPIS_LIB"]
-        except KeyError:
-            # Do not put papis.config.get because get is a special function
-            # that also needs the library to see if some key was overridden!
-            lib = papis.config.get_default_settings(key="default-library")
+        lib = os.environ["PAPIS_LIB"]
+    except KeyError:
+        # Do not put papis.config.get because get is a special function
+        # that also needs the library to see if some key was overridden!
+        lib = papis.config.get_default_settings(key="default-library")
     return lib
 
 
@@ -891,10 +966,10 @@ def reset_configuration():
     :returns: Configuration object
     :rtype:  papis.config.Configuration
     """
-    global CONFIGURATION
-    if CONFIGURATION is not None:
+    global _CONFIGURATION
+    if _CONFIGURATION is not None:
         logger.warning("Overwriting previous configuration")
-    CONFIGURATION = None
+    _CONFIGURATION = None
     logger.debug("Resetting configuration")
     return get_configuration()
 
