@@ -15,5 +15,14 @@ class DefaultSettingValueMissing(Exception):
     """
 
     def __init__(self, key):
-        message = "\nValue for '%s' is not at all registered and known" % (key)
+        message = """
+
+    The configuration setting '{0}' is not defined.
+    Try setting its value in your configuration file as such:
+
+        [settings]
+        {0} = some-value
+
+    Don't forget to check the documentation.
+        """.format(key)
         super(DefaultSettingValueMissing, self).__init__(message)
